@@ -1,6 +1,7 @@
 from .autocomplete import AutoCompleteMixin, autocomplete
 from .rest import AngularFormMixin
 from .foreign_key import foreign_field_autocomplete, ForeignFieldAutoCompleteMixin, M2MEnabledMetadata
+from .linked_form import linked_form, linked_forms
 
 __all__ = [
     AutoCompleteMixin,
@@ -8,5 +9,7 @@ __all__ = [
     autocomplete,
     foreign_field_autocomplete,
     ForeignFieldAutoCompleteMixin,
-    M2MEnabledMetadata
+    M2MEnabledMetadata,
+    linked_form,
+    linked_forms
 ]
